==> ejc-analyticdatas-impl-3.0.0-20230530.055734-25-sources.jar: com/ejianc/foundation/analyticdatas/bean/TenantDataEntity.java <==
package com.ejianc.foundation.analyticdatas.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

@TableName("ejc_analyticdatas_tenantdata")
public class TenantDataEntity extends BaseEntity {

	private static final long serialVersionUID = 1L;

	@TableField(value = "analytic_tenant_id")
	private Long analyticTenantId; // 租户ID

	@TableField(value = "tenant_name")
	private String tenantName; // 租户名称

	@TableField(value = "business_type")
	private String businessType; // 申请类型 ： 1：建筑施工单位， 2：供应商， 3：其他

	@TableField(value = "super_admin_id")
	private Long superAdminId; // 超级管理员ID

	@TableField(value = "super_admin_usercode")
	private String superAdminUserCode; // 超级管理员账号

	@TableField(value = "social_credit_code")
	private String socialCreditCode; // 统一社会信用代码

	public Long getAnalyticTenantId() {
		return analyticTenantId;
	}

	public void setAnalyticTenantId(Long analyticTenantId) {
		this.analyticTenantId = analyticTenantId;
	}

	public String getTenantName() {
		return tenantName;
	}

	public void setTenantName(String tenantName) {
		this.tenantName = tenantName;
	}

	public String getBusinessType() {
		return businessType;
	}

	public void setBusinessType(String businessType) {
		this.businessType = businessType;
	}

	public Long getSuperAdminId() {
		return superAdminId;
	}

	public void setSuperAdminId(Long superAdminId) {
		this.superAdminId = superAdminId;
	}

	public String getSuperAdminUserCode() {
		return superAdminUserCode;
	}

	public void setSuperAdminUserCode(String superAdminUserCode) {
		this.superAdminUserCode = superAdminUserCode;
	}

	public String getSocialCreditCode() {
		return socialCreditCode;
	}

	public void setSocialCreditCode(String socialCreditCode) {
		this.socialCreditCode = socialCreditCode;
	}

}

==> ejc-analyticdatas-impl-3.0.0-20251124.122953-113-sources.jar: com/ejianc/foundation/analyticdatas/bean/TenantDataEntity.java <==
package com.ejianc.foundation.analyticdatas.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

@TableName("ejc_analyticdatas_tenantdata")
public class TenantDataEntity extends BaseEntity {

	private static final long serialVersionUID = 1L;

	@TableField(value = "analytic_tenant_id")
	private Long analyticTenantId; // 租户ID

	@TableField(value = "tenant_name")
	private String tenantName; // 租户名称

	@TableField(value = "business_type")
	private String businessType; // 申请类型 ： 1：建筑施工单位， 2：供应商， 3：其他

	@TableField(value = "super_admin_id")
	private Long superAdminId; // 超级管理员ID

	@TableField(value = "super_admin_usercode")
	private String superAdminUserCode; // 超级管理员账号

	@TableField(value = "social_credit_code")
	private String socialCreditCode; // 统一社会信用代码

	@TableField(value = "state")
	private Integer state; // 租户状态(1:启用，0：停用)

	public Long getAnalyticTenantId() {
		return analyticTenantId;
	}

	public void setAnalyticTenantId(Long analyticTenantId) {
		this.analyticTenantId = analyticTenantId;
	}

	public String getTenantName() {
		return tenantName;
	}

	public void setTenantName(String tenantName) {
		this.tenantName = tenantName;
	}

	public String getBusinessType() {
		return businessType;
	}

	public void setBusinessType(String businessType) {
		this.businessType = businessType;
	}

	public Long getSuperAdminId() {
		return superAdminId;
	}

	public void setSuperAdminId(Long superAdminId) {
		this.superAdminId = superAdminId;
	}

	public String getSuperAdminUserCode() {
		return superAdminUserCode;
	}

	public void setSuperAdminUserCode(String superAdminUserCode) {
		this.superAdminUserCode = superAdminUserCode;
	}

	public String getSocialCreditCode() {
		return socialCreditCode;
	}

	public void setSocialCreditCode(String socialCreditCode) {
		this.socialCreditCode = socialCreditCode;
	}

	public Integer getState() {
		return state;
	}

	public void setState(Integer state) {
		this.state = state;
	}
}
